pdupes package
==============

Submodules
----------

pdupes.cli module
-----------------

.. automodule:: pdupes.cli
    :members:
    :undoc-members:
    :show-inheritance:

pdupes.duplicatefinder module
-----------------------------

.. automodule:: pdupes.duplicatefinder
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pdupes
    :members:
    :undoc-members:
    :show-inheritance:
